@@ -6,7 +6,7 @@ from .ui.app import TailscaleTui
 
 
 @click.command()
-@click.argument("token", default=None, required=False)
+@click.option("--token", default=None, help="Tailscale API token")
 def run(token) -> None:
     if token:
         config_path = get_config_path()
